@@ -1,3 +1,19 @@
+# Copyright (C) 2020  Brodie Gaslam
+# 
+# This file is part of "unitizer"
+# 
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# Go to <https://www.r-project.org/Licenses/GPL-2> for a copy of the license.
+
 #' @include item.R
 #' @include unitizer.R
 #' @include class_unions.R
@@ -17,14 +33,21 @@ NULL
 setGeneric("browsePrep", function(x, mode, ...) standardGeneric("browsePrep"))
 setMethod("browsePrep", c("unitizer", "character"), valueClass="unitizerBrowse",
   function(
-    x, mode, hist.con=NULL, interactive=FALSE, start.at.browser=FALSE, ...
+    x, mode, hist.con=NULL, interactive=FALSE, start.at.browser=FALSE,
+    use.diff=TRUE, ...
   ) {
     if(length(mode) != 1L || !mode %in% c("review", "unitize"))
       stop("Argument `mode` must be one of \"review\" or \"unitize\"")
     unitizer.browse <- new(
       "unitizerBrowse", mode=mode, hist.con=hist.con, interactive=interactive,
-      global=x@global, start.at.browser=start.at.browser
+      global=x@global, start.at.browser=start.at.browser, use.diff=use.diff
     )
+    # Assign the `show.diff` status to the errors, this isn't done when the
+    # tests are evaluated.
+
+    for(i in seq_along(x@tests.errorDetails))
+      x@tests.errorDetails[[i]]@.use.diff <- use.diff
+
     # - Unitize ----------------------------------------------------------------
 
     # At some point need to rationalize this to a simpler instantiator for the
@@ -288,26 +311,33 @@ setClass("unitizerBrowse", contains="unitizerList",
   slots=c(
     mapping="unitizerBrowseMapping",
     last.id="integer",          # so that `reviewNext` knows what to show next
-    last.reviewed="integer",    # so that `reviewNext` knows what headers to display
+    # so that `reviewNext` knows what headers to display
+    last.reviewed="integer",
     jumping.to="logical",       # indicate there was a re-eval jump
     hist.con="ANY",             # should be 'fileOrNULL', but setOldClass` issues
     mode="character",
     review="integer",           # counter to figure out when browse/review menu
     inspect.all="logical",      # force inspection of all elements
-    navigating="logical",       # user has triggered at least one navigation command
+    # user has triggered at least one navigation command
+    navigating="logical",
     browsing="logical",         # current test selected via browse
     human="logical",            # whether user has had any interaction at all
-    re.eval="integer",          # so navprompt can communicate back re-eval status
+    # so navprompt can communicate back re-eval status
+    re.eval="integer",
     force.up="logical",         # force update even if no changes
     interactive="logical",      # whether to browse in interactive mode
-    interactive.error="logical",# whether in non-interactive mode but required input
+    # whether in non-interactive mode but required input
+    interactive.error="logical",
     global="unitizerGlobal",    # object for global settings
-    auto.accept="logical",      # indicate whether any auto-accepts were triggered
+    # indicate whether any auto-accepts were triggered
+    auto.accept="logical",
     multi="logical",            # whether many unitizers are being browsed
     multi.quit="logical",       # whether many unitizers are being browsed
     # whether to show browser first, also disables warnings about reviewing
     # tests that are not usually reviewed
-    start.at.browser="logical"
+    start.at.browser="logical",
+    use.diff="logical"          # Whether to use a diff in failure comparisons
+
   ),
   prototype=list(
     mapping=new("unitizerBrowseMapping"),
@@ -405,7 +435,7 @@ setMethod(
 setMethod("as.character", "unitizerBrowse", valueClass="character",
   function(x, width=0L, ...) {
     if(!is.numeric(width) || width < 0 || length(width) != 1L) {
-      stop("Argument `width` must be a one length numeric.")
+      stop("Argument `width` must be a positive scalar numeric.")
     }
     width <- as.integer(width)
     width.max <- if(width) width else getOption("width")
@@ -427,8 +457,9 @@ setMethod("as.character", "unitizerBrowse", valueClass="character",
     num.pad <- ". "
     front.pad <- "  "
     rev.type <- format(as.character(x@mapping@review.type), justify="right")
-    rev.fail.corr <- rev.type %in% c("Failed", "Corrupted")
-    rev.new <- rev.type == "New"
+    rev.fail.corr <- x@mapping@review.type %in% c("Failed", "Corrupted")
+    rev.new <- x@mapping@review.type == "New"
+
     if(isTRUE(x@global$unitizer.opts[["unitizer.color"]])) {
       rev.type[rev.fail.corr] <- crayon::yellow(rev.type[rev.fail.corr])
       rev.type[rev.new] <- crayon::blue(rev.type[rev.new])
@@ -634,8 +665,9 @@ setMethod("+", c("unitizerBrowse", "unitizerBrowseSection"), valueClass="unitize
 
     mapping.new <- new("unitizerBrowseMapping",
       # This id tracks the order of tests as we intend to review them
+      # is it possible for sum(item.count) to be zero?
       item.id=(max.item + 1L):(max.item + sum(item.count)),
-      item.id.rel=unlist(lapply(item.count, function(x) seq(len=x))),
+      item.id.rel=unlist(lapply(item.count, function(x) seq(length.out=x))),
       item.id.orig=vapply(sec.item.list, slot, 1L, "id"),
       item.ref=vapply(sec.item.list, slot, FALSE, "reference"),
       sec.id=rep(length(e1), sum(item.count)),
