@@ -1,3 +1,19 @@
+# Copyright (C) 2020  Brodie Gaslam
+# 
+# This file is part of "unitizer"
+# 
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# Go to <https://www.r-project.org/Licenses/GPL-2> for a copy of the license.
+
 #' @include item.R
 #' @include item.sub.R
 #' @include section.R
@@ -449,7 +465,7 @@ setMethod("show", "unitizerObjectListSummary",
 
     # Legends
 
-    if(any(review.req || object@updated))
+    if(any(review.req | object@updated))
       meta_word_cat("Legend:", trail.nl=FALSE)
     if(any(review.req & !object@updated))
       meta_word_cat("* `unitizer` requires review", trail.nl=FALSE)
